# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.trainerd.v1 import trainerd_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2


class TrainerdServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Train = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.trainerd.v1.TrainerdService/Train',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.TrainRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.TrainResponse.FromString,
                )
        self.Explain = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.trainerd.v1.TrainerdService/Explain',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.ExplainRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.ExplainResponse.FromString,
                )
        self.Forecast = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.trainerd.v1.TrainerdService/Forecast',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.ForecastRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.ForecastResponse.FromString,
                )
        self.Test = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.trainerd.v1.TrainerdService/Test',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.TestRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.TestResponse.FromString,
                )
        self.TrainEnsemble = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.trainerd.v1.TrainerdService/TrainEnsemble',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.TrainEnsembleRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.TrainResponse.FromString,
                )
        self.TrainDriftDetector = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.trainerd.v1.TrainerdService/TrainDriftDetector',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.TrainDriftDetectorRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.TrainResponse.FromString,
                )
        self.TestEnsemble = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.trainerd.v1.TrainerdService/TestEnsemble',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.TestEnsembleRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.TestResponse.FromString,
                )
        self.Shutdown = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.trainerd.v1.TrainerdService/Shutdown',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.ShutdownRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.ShutdownResponse.FromString,
                )


class TrainerdServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Train(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Explain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Forecast(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Test(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TrainEnsemble(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TrainDriftDetector(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TestEnsemble(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Shutdown(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TrainerdServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Train': grpc.unary_unary_rpc_method_handler(
                    servicer.Train,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.TrainRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.TrainResponse.SerializeToString,
            ),
            'Explain': grpc.unary_unary_rpc_method_handler(
                    servicer.Explain,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.ExplainRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.ExplainResponse.SerializeToString,
            ),
            'Forecast': grpc.unary_unary_rpc_method_handler(
                    servicer.Forecast,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.ForecastRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.ForecastResponse.SerializeToString,
            ),
            'Test': grpc.unary_unary_rpc_method_handler(
                    servicer.Test,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.TestRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.TestResponse.SerializeToString,
            ),
            'TrainEnsemble': grpc.unary_unary_rpc_method_handler(
                    servicer.TrainEnsemble,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.TrainEnsembleRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.TrainResponse.SerializeToString,
            ),
            'TrainDriftDetector': grpc.unary_unary_rpc_method_handler(
                    servicer.TrainDriftDetector,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.TrainDriftDetectorRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.TrainResponse.SerializeToString,
            ),
            'TestEnsemble': grpc.unary_unary_rpc_method_handler(
                    servicer.TestEnsemble,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.TestEnsembleRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.TestResponse.SerializeToString,
            ),
            'Shutdown': grpc.unary_unary_rpc_method_handler(
                    servicer.Shutdown,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.ShutdownRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.ShutdownResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.trainerd.v1.TrainerdService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class TrainerdService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Train(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.trainerd.v1.TrainerdService/Train',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.TrainRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.TrainResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Explain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.trainerd.v1.TrainerdService/Explain',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.ExplainRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.ExplainResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Forecast(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.trainerd.v1.TrainerdService/Forecast',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.ForecastRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.ForecastResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Test(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.trainerd.v1.TrainerdService/Test',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.TestRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.TestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TrainEnsemble(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.trainerd.v1.TrainerdService/TrainEnsemble',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.TrainEnsembleRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.TrainResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TrainDriftDetector(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.trainerd.v1.TrainerdService/TrainDriftDetector',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.TrainDriftDetectorRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.TrainResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TestEnsemble(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.trainerd.v1.TrainerdService/TestEnsemble',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.TestEnsembleRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.TestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Shutdown(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.trainerd.v1.TrainerdService/Shutdown',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.ShutdownRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_trainerd_dot_v1_dot_trainerd__pb2.ShutdownResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.license.v1 import license_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_license_dot_v1_dot_license__pb2


class LicenseServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListLicenses = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.license.v1.LicenseService/ListLicenses',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_license_dot_v1_dot_license__pb2.ListLicensesRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_license_dot_v1_dot_license__pb2.ListLicensesResponse.FromString,
                )
        self.CreateLicense = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.license.v1.LicenseService/CreateLicense',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_license_dot_v1_dot_license__pb2.CreateLicenseRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_license_dot_v1_dot_license__pb2.CreateLicenseResponse.FromString,
                )
        self.CreateLicenseFromKey = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.license.v1.LicenseService/CreateLicenseFromKey',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_license_dot_v1_dot_license__pb2.CreateLicenseFromKeyRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_license_dot_v1_dot_license__pb2.CreateLicenseResponse.FromString,
                )
        self.GetLicense = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.license.v1.LicenseService/GetLicense',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_license_dot_v1_dot_license__pb2.GetLicenseRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_license_dot_v1_dot_license__pb2.GetLicenseResponse.FromString,
                )
        self.UpdateLicense = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.license.v1.LicenseService/UpdateLicense',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_license_dot_v1_dot_license__pb2.UpdateLicenseRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_license_dot_v1_dot_license__pb2.UpdateLicenseResponse.FromString,
                )
        self.DeleteLicense = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.license.v1.LicenseService/DeleteLicense',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_license_dot_v1_dot_license__pb2.DeleteLicenseRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_license_dot_v1_dot_license__pb2.DeleteLicenseResponse.FromString,
                )


class LicenseServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListLicenses(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateLicense(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateLicenseFromKey(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLicense(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateLicense(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteLicense(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_LicenseServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListLicenses': grpc.unary_unary_rpc_method_handler(
                    servicer.ListLicenses,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_license_dot_v1_dot_license__pb2.ListLicensesRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_license_dot_v1_dot_license__pb2.ListLicensesResponse.SerializeToString,
            ),
            'CreateLicense': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateLicense,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_license_dot_v1_dot_license__pb2.CreateLicenseRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_license_dot_v1_dot_license__pb2.CreateLicenseResponse.SerializeToString,
            ),
            'CreateLicenseFromKey': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateLicenseFromKey,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_license_dot_v1_dot_license__pb2.CreateLicenseFromKeyRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_license_dot_v1_dot_license__pb2.CreateLicenseResponse.SerializeToString,
            ),
            'GetLicense': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLicense,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_license_dot_v1_dot_license__pb2.GetLicenseRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_license_dot_v1_dot_license__pb2.GetLicenseResponse.SerializeToString,
            ),
            'UpdateLicense': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateLicense,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_license_dot_v1_dot_license__pb2.UpdateLicenseRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_license_dot_v1_dot_license__pb2.UpdateLicenseResponse.SerializeToString,
            ),
            'DeleteLicense': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteLicense,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_license_dot_v1_dot_license__pb2.DeleteLicenseRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_license_dot_v1_dot_license__pb2.DeleteLicenseResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.license.v1.LicenseService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class LicenseService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListLicenses(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.license.v1.LicenseService/ListLicenses',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_license_dot_v1_dot_license__pb2.ListLicensesRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_license_dot_v1_dot_license__pb2.ListLicensesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateLicense(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.license.v1.LicenseService/CreateLicense',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_license_dot_v1_dot_license__pb2.CreateLicenseRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_license_dot_v1_dot_license__pb2.CreateLicenseResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateLicenseFromKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.license.v1.LicenseService/CreateLicenseFromKey',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_license_dot_v1_dot_license__pb2.CreateLicenseFromKeyRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_license_dot_v1_dot_license__pb2.CreateLicenseResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLicense(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.license.v1.LicenseService/GetLicense',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_license_dot_v1_dot_license__pb2.GetLicenseRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_license_dot_v1_dot_license__pb2.GetLicenseResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateLicense(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.license.v1.LicenseService/UpdateLicense',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_license_dot_v1_dot_license__pb2.UpdateLicenseRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_license_dot_v1_dot_license__pb2.UpdateLicenseResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteLicense(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.license.v1.LicenseService/DeleteLicense',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_license_dot_v1_dot_license__pb2.DeleteLicenseRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_license_dot_v1_dot_license__pb2.DeleteLicenseResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/lab/v1/lab.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7github.com/metaprov/modelaapi/services/lab/v1/lab.proto\x12-github.com.metaprov.modelaapi.services.lab.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\"\xe8\x01\n\x0fListLabsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12Z\n\x06labels\x18\x02 \x03(\x0b\x32J.github.com.metaprov.modelaapi.services.lab.v1.ListLabsRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"y\n\x10ListLabsResponse\x12L\n\x04labs\x18\x01 \x01(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.LabList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\r\n\x0bLabResponse\"[\n\x10\x43reateLabRequest\x12G\n\x03lab\x18\x01 \x01(\x0b\x32:.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Lab\"\x13\n\x11\x43reateLabResponse\"\x8b\x01\n\x10UpdateLabRequest\x12G\n\x03lab\x18\x01 \x01(\x0b\x32:.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Lab\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x13\n\x11UpdateLabResponse\"0\n\rGetLabRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"g\n\x0eGetLabResponse\x12G\n\x03lab\x18\x01 \x01(\x0b\x32:.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Lab\x12\x0c\n\x04yaml\x18\x02 \x01(\t\":\n\x17GetLabNamespacesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"o\n\x18GetLabNamespacesResponse\x12S\n\nnamespaces\x18\x01 \x03(\x0b\x32?.github.com.metaprov.modelaapi.services.common.v1.NamespaceInfo\"3\n\x10\x44\x65leteLabRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x13\n\x11\x44\x65leteLabResponse2\x94\x07\n\nLabService\x12\xa9\x01\n\x08ListLabs\x12>.github.com.metaprov.modelaapi.services.lab.v1.ListLabsRequest\x1a?.github.com.metaprov.modelaapi.services.lab.v1.ListLabsResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/v1/labs/{namespace}\x12\xa3\x01\n\tCreateLab\x12?.github.com.metaprov.modelaapi.services.lab.v1.CreateLabRequest\x1a@.github.com.metaprov.modelaapi.services.lab.v1.CreateLabResponse\"\x13\x82\xd3\xe4\x93\x02\r\"\x08/v1/labs:\x01*\x12\xaa\x01\n\x06GetLab\x12<.github.com.metaprov.modelaapi.services.lab.v1.GetLabRequest\x1a=.github.com.metaprov.modelaapi.services.lab.v1.GetLabResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v1/labs/{namespace}/{name}\x12\xd0\x01\n\tUpdateLab\x12?.github.com.metaprov.modelaapi.services.lab.v1.UpdateLabRequest\x1a@.github.com.metaprov.modelaapi.services.lab.v1.UpdateLabResponse\"@\x82\xd3\xe4\x93\x02:\x1a\x35/v1/labs/{lab.metadata.namespace}/{lab.metadata.name}:\x01*\x12\xb3\x01\n\tDeleteLab\x12?.github.com.metaprov.modelaapi.services.lab.v1.DeleteLabRequest\x1a@.github.com.metaprov.modelaapi.services.lab.v1.DeleteLabResponse\"#\x82\xd3\xe4\x93\x02\x1d*\x1b/v1/labs/{namespace}/{name}B/Z-github.com/metaprov/modelaapi/services/lab/v1b\x06proto3')



_LISTLABSREQUEST = DESCRIPTOR.message_types_by_name['ListLabsRequest']
_LISTLABSREQUEST_LABELSENTRY = _LISTLABSREQUEST.nested_types_by_name['LabelsEntry']
_LISTLABSRESPONSE = DESCRIPTOR.message_types_by_name['ListLabsResponse']
_LABRESPONSE = DESCRIPTOR.message_types_by_name['LabResponse']
_CREATELABREQUEST = DESCRIPTOR.message_types_by_name['CreateLabRequest']
_CREATELABRESPONSE = DESCRIPTOR.message_types_by_name['CreateLabResponse']
_UPDATELABREQUEST = DESCRIPTOR.message_types_by_name['UpdateLabRequest']
_UPDATELABRESPONSE = DESCRIPTOR.message_types_by_name['UpdateLabResponse']
_GETLABREQUEST = DESCRIPTOR.message_types_by_name['GetLabRequest']
_GETLABRESPONSE = DESCRIPTOR.message_types_by_name['GetLabResponse']
_GETLABNAMESPACESREQUEST = DESCRIPTOR.message_types_by_name['GetLabNamespacesRequest']
_GETLABNAMESPACESRESPONSE = DESCRIPTOR.message_types_by_name['GetLabNamespacesResponse']
_DELETELABREQUEST = DESCRIPTOR.message_types_by_name['DeleteLabRequest']
_DELETELABRESPONSE = DESCRIPTOR.message_types_by_name['DeleteLabResponse']
ListLabsRequest = _reflection.GeneratedProtocolMessageType('ListLabsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTLABSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.lab.v1.lab_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.lab.v1.ListLabsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTLABSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.lab.v1.lab_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.lab.v1.ListLabsRequest)
  })
_sym_db.RegisterMessage(ListLabsRequest)
_sym_db.RegisterMessage(ListLabsRequest.LabelsEntry)

ListLabsResponse = _reflection.GeneratedProtocolMessageType('ListLabsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTLABSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.lab.v1.lab_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.lab.v1.ListLabsResponse)
  })
_sym_db.RegisterMessage(ListLabsResponse)

LabResponse = _reflection.GeneratedProtocolMessageType('LabResponse', (_message.Message,), {
  'DESCRIPTOR' : _LABRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.lab.v1.lab_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.lab.v1.LabResponse)
  })
_sym_db.RegisterMessage(LabResponse)

CreateLabRequest = _reflection.GeneratedProtocolMessageType('CreateLabRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATELABREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.lab.v1.lab_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.lab.v1.CreateLabRequest)
  })
_sym_db.RegisterMessage(CreateLabRequest)

CreateLabResponse = _reflection.GeneratedProtocolMessageType('CreateLabResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATELABRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.lab.v1.lab_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.lab.v1.CreateLabResponse)
  })
_sym_db.RegisterMessage(CreateLabResponse)

UpdateLabRequest = _reflection.GeneratedProtocolMessageType('UpdateLabRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATELABREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.lab.v1.lab_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.lab.v1.UpdateLabRequest)
  })
_sym_db.RegisterMessage(UpdateLabRequest)

UpdateLabResponse = _reflection.GeneratedProtocolMessageType('UpdateLabResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATELABRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.lab.v1.lab_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.lab.v1.UpdateLabResponse)
  })
_sym_db.RegisterMessage(UpdateLabResponse)

GetLabRequest = _reflection.GeneratedProtocolMessageType('GetLabRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLABREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.lab.v1.lab_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.lab.v1.GetLabRequest)
  })
_sym_db.RegisterMessage(GetLabRequest)

GetLabResponse = _reflection.GeneratedProtocolMessageType('GetLabResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETLABRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.lab.v1.lab_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.lab.v1.GetLabResponse)
  })
_sym_db.RegisterMessage(GetLabResponse)

GetLabNamespacesRequest = _reflection.GeneratedProtocolMessageType('GetLabNamespacesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLABNAMESPACESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.lab.v1.lab_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.lab.v1.GetLabNamespacesRequest)
  })
_sym_db.RegisterMessage(GetLabNamespacesRequest)

GetLabNamespacesResponse = _reflection.GeneratedProtocolMessageType('GetLabNamespacesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETLABNAMESPACESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.lab.v1.lab_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.lab.v1.GetLabNamespacesResponse)
  })
_sym_db.RegisterMessage(GetLabNamespacesResponse)

DeleteLabRequest = _reflection.GeneratedProtocolMessageType('DeleteLabRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETELABREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.lab.v1.lab_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.lab.v1.DeleteLabRequest)
  })
_sym_db.RegisterMessage(DeleteLabRequest)

DeleteLabResponse = _reflection.GeneratedProtocolMessageType('DeleteLabResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETELABRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.lab.v1.lab_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.lab.v1.DeleteLabResponse)
  })
_sym_db.RegisterMessage(DeleteLabResponse)

_LABSERVICE = DESCRIPTOR.services_by_name['LabService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/metaprov/modelaapi/services/lab/v1'
  _LISTLABSREQUEST_LABELSENTRY._options = None
  _LISTLABSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _LABSERVICE.methods_by_name['ListLabs']._options = None
  _LABSERVICE.methods_by_name['ListLabs']._serialized_options = b'\202\323\344\223\002\026\022\024/v1/labs/{namespace}'
  _LABSERVICE.methods_by_name['CreateLab']._options = None
  _LABSERVICE.methods_by_name['CreateLab']._serialized_options = b'\202\323\344\223\002\r\"\010/v1/labs:\001*'
  _LABSERVICE.methods_by_name['GetLab']._options = None
  _LABSERVICE.methods_by_name['GetLab']._serialized_options = b'\202\323\344\223\002\035\022\033/v1/labs/{namespace}/{name}'
  _LABSERVICE.methods_by_name['UpdateLab']._options = None
  _LABSERVICE.methods_by_name['UpdateLab']._serialized_options = b'\202\323\344\223\002:\0325/v1/labs/{lab.metadata.namespace}/{lab.metadata.name}:\001*'
  _LABSERVICE.methods_by_name['DeleteLab']._options = None
  _LABSERVICE.methods_by_name['DeleteLab']._serialized_options = b'\202\323\344\223\002\035*\033/v1/labs/{namespace}/{name}'
  _LISTLABSREQUEST._serialized_start=305
  _LISTLABSREQUEST._serialized_end=537
  _LISTLABSREQUEST_LABELSENTRY._serialized_start=492
  _LISTLABSREQUEST_LABELSENTRY._serialized_end=537
  _LISTLABSRESPONSE._serialized_start=539
  _LISTLABSRESPONSE._serialized_end=660
  _LABRESPONSE._serialized_start=662
  _LABRESPONSE._serialized_end=675
  _CREATELABREQUEST._serialized_start=677
  _CREATELABREQUEST._serialized_end=768
  _CREATELABRESPONSE._serialized_start=770
  _CREATELABRESPONSE._serialized_end=789
  _UPDATELABREQUEST._serialized_start=792
  _UPDATELABREQUEST._serialized_end=931
  _UPDATELABRESPONSE._serialized_start=933
  _UPDATELABRESPONSE._serialized_end=952
  _GETLABREQUEST._serialized_start=954
  _GETLABREQUEST._serialized_end=1002
  _GETLABRESPONSE._serialized_start=1004
  _GETLABRESPONSE._serialized_end=1107
  _GETLABNAMESPACESREQUEST._serialized_start=1109
  _GETLABNAMESPACESREQUEST._serialized_end=1167
  _GETLABNAMESPACESRESPONSE._serialized_start=1169
  _GETLABNAMESPACESRESPONSE._serialized_end=1280
  _DELETELABREQUEST._serialized_start=1282
  _DELETELABREQUEST._serialized_end=1333
  _DELETELABRESPONSE._serialized_start=1335
  _DELETELABRESPONSE._serialized_end=1354
  _LABSERVICE._serialized_start=1357
  _LABSERVICE._serialized_end=2273
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/featurehistogram/v1/featurehistogram.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nQgithub.com/metaprov/modelaapi/services/featurehistogram/v1/featurehistogram.proto\x12:github.com.metaprov.modelaapi.services.featurehistogram.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\x8f\x02\n\x1cListFeatureHistogramsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12t\n\x06labels\x18\x02 \x03(\x0b\x32\x64.github.com.metaprov.modelaapi.services.featurehistogram.v1.ListFeatureHistogramsRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x98\x01\n\x1dListFeatureHistogramsResponse\x12^\n\nhistograms\x18\x01 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureHistogramList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x93\x01\n\x1d\x43reateFeatureHistogramRequest\x12Y\n\thistogram\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureHistogram\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\" \n\x1e\x43reateFeatureHistogramResponse\"\xaa\x01\n\x1dUpdateFeatureHistogramRequest\x12Y\n\thistogram\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureHistogram\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\" \n\x1eUpdateFeatureHistogramResponse\"=\n\x1aGetFeatureHistogramRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x86\x01\n\x1bGetFeatureHistogramResponse\x12Y\n\thistogram\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureHistogram\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"@\n\x1d\x44\x65leteFeatureHistogramRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\" \n\x1e\x44\x65leteFeatureHistogramResponse2\xb3\n\n\x17\x46\x65\x61tureHistogramService\x12\xf7\x01\n\x15ListFeatureHistograms\x12X.github.com.metaprov.modelaapi.services.featurehistogram.v1.ListFeatureHistogramsRequest\x1aY.github.com.metaprov.modelaapi.services.featurehistogram.v1.ListFeatureHistogramsResponse\")\x82\xd3\xe4\x93\x02#\x12!/v1/featurehistograms/{namespace}\x12\xf1\x01\n\x16\x43reateFeatureHistogram\x12Y.github.com.metaprov.modelaapi.services.featurehistogram.v1.CreateFeatureHistogramRequest\x1aZ.github.com.metaprov.modelaapi.services.featurehistogram.v1.CreateFeatureHistogramResponse\" \x82\xd3\xe4\x93\x02\x1a\"\x15/v1/featurehistograms:\x01*\x12\xf8\x01\n\x13GetFeatureHistogram\x12V.github.com.metaprov.modelaapi.services.featurehistogram.v1.GetFeatureHistogramRequest\x1aW.github.com.metaprov.modelaapi.services.featurehistogram.v1.GetFeatureHistogramResponse\"0\x82\xd3\xe4\x93\x02*\x12(/v1/featurehistograms/{namespace}/{name}\x12\xaa\x02\n\x16UpdateFeatureHistogram\x12Y.github.com.metaprov.modelaapi.services.featurehistogram.v1.UpdateFeatureHistogramRequest\x1aZ.github.com.metaprov.modelaapi.services.featurehistogram.v1.UpdateFeatureHistogramResponse\"Y\x82\xd3\xe4\x93\x02S\x1aN/v1/featurehistograms/{histogram.metadata.namespace}/{histogram.metadata.name}:\x01*\x12\x81\x02\n\x16\x44\x65leteFeatureHistogram\x12Y.github.com.metaprov.modelaapi.services.featurehistogram.v1.DeleteFeatureHistogramRequest\x1aZ.github.com.metaprov.modelaapi.services.featurehistogram.v1.DeleteFeatureHistogramResponse\"0\x82\xd3\xe4\x93\x02**(/v1/featurehistograms/{namespace}/{name}B<Z:github.com/metaprov/modelaapi/services/featurehistogram/v1b\x06proto3')



_LISTFEATUREHISTOGRAMSREQUEST = DESCRIPTOR.message_types_by_name['ListFeatureHistogramsRequest']
_LISTFEATUREHISTOGRAMSREQUEST_LABELSENTRY = _LISTFEATUREHISTOGRAMSREQUEST.nested_types_by_name['LabelsEntry']
_LISTFEATUREHISTOGRAMSRESPONSE = DESCRIPTOR.message_types_by_name['ListFeatureHistogramsResponse']
_CREATEFEATUREHISTOGRAMREQUEST = DESCRIPTOR.message_types_by_name['CreateFeatureHistogramRequest']
_CREATEFEATUREHISTOGRAMRESPONSE = DESCRIPTOR.message_types_by_name['CreateFeatureHistogramResponse']
_UPDATEFEATUREHISTOGRAMREQUEST = DESCRIPTOR.message_types_by_name['UpdateFeatureHistogramRequest']
_UPDATEFEATUREHISTOGRAMRESPONSE = DESCRIPTOR.message_types_by_name['UpdateFeatureHistogramResponse']
_GETFEATUREHISTOGRAMREQUEST = DESCRIPTOR.message_types_by_name['GetFeatureHistogramRequest']
_GETFEATUREHISTOGRAMRESPONSE = DESCRIPTOR.message_types_by_name['GetFeatureHistogramResponse']
_DELETEFEATUREHISTOGRAMREQUEST = DESCRIPTOR.message_types_by_name['DeleteFeatureHistogramRequest']
_DELETEFEATUREHISTOGRAMRESPONSE = DESCRIPTOR.message_types_by_name['DeleteFeatureHistogramResponse']
ListFeatureHistogramsRequest = _reflection.GeneratedProtocolMessageType('ListFeatureHistogramsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTFEATUREHISTOGRAMSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.featurehistogram.v1.featurehistogram_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurehistogram.v1.ListFeatureHistogramsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTFEATUREHISTOGRAMSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurehistogram.v1.featurehistogram_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurehistogram.v1.ListFeatureHistogramsRequest)
  })
_sym_db.RegisterMessage(ListFeatureHistogramsRequest)
_sym_db.RegisterMessage(ListFeatureHistogramsRequest.LabelsEntry)

ListFeatureHistogramsResponse = _reflection.GeneratedProtocolMessageType('ListFeatureHistogramsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATUREHISTOGRAMSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurehistogram.v1.featurehistogram_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurehistogram.v1.ListFeatureHistogramsResponse)
  })
_sym_db.RegisterMessage(ListFeatureHistogramsResponse)

CreateFeatureHistogramRequest = _reflection.GeneratedProtocolMessageType('CreateFeatureHistogramRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATUREHISTOGRAMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurehistogram.v1.featurehistogram_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurehistogram.v1.CreateFeatureHistogramRequest)
  })
_sym_db.RegisterMessage(CreateFeatureHistogramRequest)

CreateFeatureHistogramResponse = _reflection.GeneratedProtocolMessageType('CreateFeatureHistogramResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATUREHISTOGRAMRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurehistogram.v1.featurehistogram_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurehistogram.v1.CreateFeatureHistogramResponse)
  })
_sym_db.RegisterMessage(CreateFeatureHistogramResponse)

UpdateFeatureHistogramRequest = _reflection.GeneratedProtocolMessageType('UpdateFeatureHistogramRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATUREHISTOGRAMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurehistogram.v1.featurehistogram_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurehistogram.v1.UpdateFeatureHistogramRequest)
  })
_sym_db.RegisterMessage(UpdateFeatureHistogramRequest)

UpdateFeatureHistogramResponse = _reflection.GeneratedProtocolMessageType('UpdateFeatureHistogramResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATUREHISTOGRAMRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurehistogram.v1.featurehistogram_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurehistogram.v1.UpdateFeatureHistogramResponse)
  })
_sym_db.RegisterMessage(UpdateFeatureHistogramResponse)

GetFeatureHistogramRequest = _reflection.GeneratedProtocolMessageType('GetFeatureHistogramRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREHISTOGRAMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurehistogram.v1.featurehistogram_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurehistogram.v1.GetFeatureHistogramRequest)
  })
_sym_db.RegisterMessage(GetFeatureHistogramRequest)

GetFeatureHistogramResponse = _reflection.GeneratedProtocolMessageType('GetFeatureHistogramResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREHISTOGRAMRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurehistogram.v1.featurehistogram_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurehistogram.v1.GetFeatureHistogramResponse)
  })
_sym_db.RegisterMessage(GetFeatureHistogramResponse)

DeleteFeatureHistogramRequest = _reflection.GeneratedProtocolMessageType('DeleteFeatureHistogramRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATUREHISTOGRAMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurehistogram.v1.featurehistogram_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurehistogram.v1.DeleteFeatureHistogramRequest)
  })
_sym_db.RegisterMessage(DeleteFeatureHistogramRequest)

DeleteFeatureHistogramResponse = _reflection.GeneratedProtocolMessageType('DeleteFeatureHistogramResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATUREHISTOGRAMRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurehistogram.v1.featurehistogram_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurehistogram.v1.DeleteFeatureHistogramResponse)
  })
_sym_db.RegisterMessage(DeleteFeatureHistogramResponse)

_FEATUREHISTOGRAMSERVICE = DESCRIPTOR.services_by_name['FeatureHistogramService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z:github.com/metaprov/modelaapi/services/featurehistogram/v1'
  _LISTFEATUREHISTOGRAMSREQUEST_LABELSENTRY._options = None
  _LISTFEATUREHISTOGRAMSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _FEATUREHISTOGRAMSERVICE.methods_by_name['ListFeatureHistograms']._options = None
  _FEATUREHISTOGRAMSERVICE.methods_by_name['ListFeatureHistograms']._serialized_options = b'\202\323\344\223\002#\022!/v1/featurehistograms/{namespace}'
  _FEATUREHISTOGRAMSERVICE.methods_by_name['CreateFeatureHistogram']._options = None
  _FEATUREHISTOGRAMSERVICE.methods_by_name['CreateFeatureHistogram']._serialized_options = b'\202\323\344\223\002\032\"\025/v1/featurehistograms:\001*'
  _FEATUREHISTOGRAMSERVICE.methods_by_name['GetFeatureHistogram']._options = None
  _FEATUREHISTOGRAMSERVICE.methods_by_name['GetFeatureHistogram']._serialized_options = b'\202\323\344\223\002*\022(/v1/featurehistograms/{namespace}/{name}'
  _FEATUREHISTOGRAMSERVICE.methods_by_name['UpdateFeatureHistogram']._options = None
  _FEATUREHISTOGRAMSERVICE.methods_by_name['UpdateFeatureHistogram']._serialized_options = b'\202\323\344\223\002S\032N/v1/featurehistograms/{histogram.metadata.namespace}/{histogram.metadata.name}:\001*'
  _FEATUREHISTOGRAMSERVICE.methods_by_name['DeleteFeatureHistogram']._options = None
  _FEATUREHISTOGRAMSERVICE.methods_by_name['DeleteFeatureHistogram']._serialized_options = b'\202\323\344\223\002**(/v1/featurehistograms/{namespace}/{name}'
  _LISTFEATUREHISTOGRAMSREQUEST._serialized_start=280
  _LISTFEATUREHISTOGRAMSREQUEST._serialized_end=551
  _LISTFEATUREHISTOGRAMSREQUEST_LABELSENTRY._serialized_start=506
  _LISTFEATUREHISTOGRAMSREQUEST_LABELSENTRY._serialized_end=551
  _LISTFEATUREHISTOGRAMSRESPONSE._serialized_start=554
  _LISTFEATUREHISTOGRAMSRESPONSE._serialized_end=706
  _CREATEFEATUREHISTOGRAMREQUEST._serialized_start=709
  _CREATEFEATUREHISTOGRAMREQUEST._serialized_end=856
  _CREATEFEATUREHISTOGRAMRESPONSE._serialized_start=858
  _CREATEFEATUREHISTOGRAMRESPONSE._serialized_end=890
  _UPDATEFEATUREHISTOGRAMREQUEST._serialized_start=893
  _UPDATEFEATUREHISTOGRAMREQUEST._serialized_end=1063
  _UPDATEFEATUREHISTOGRAMRESPONSE._serialized_start=1065
  _UPDATEFEATUREHISTOGRAMRESPONSE._serialized_end=1097
  _GETFEATUREHISTOGRAMREQUEST._serialized_start=1099
  _GETFEATUREHISTOGRAMREQUEST._serialized_end=1160
  _GETFEATUREHISTOGRAMRESPONSE._serialized_start=1163
  _GETFEATUREHISTOGRAMRESPONSE._serialized_end=1297
  _DELETEFEATUREHISTOGRAMREQUEST._serialized_start=1299
  _DELETEFEATUREHISTOGRAMREQUEST._serialized_end=1363
  _DELETEFEATUREHISTOGRAMRESPONSE._serialized_start=1365
  _DELETEFEATUREHISTOGRAMRESPONSE._serialized_end=1397
  _FEATUREHISTOGRAMSERVICE._serialized_start=1400
  _FEATUREHISTOGRAMSERVICE._serialized_end=2731
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/trainerd/v1/trainerd.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_catalog_dot_v1alpha1_dot_generated__pb2
from k8s.io.api.core.v1 import generated_pb2 as k8s_dot_io_dot_api_dot_core_dot_v1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAgithub.com/metaprov/modelaapi/services/trainerd/v1/trainerd.proto\x12\x32github.com.metaprov.modelaapi.services.trainerd.v1\x1aHgithub.com/metaprov/modelaapi/pkg/apis/training/v1alpha1/generated.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\x1aGgithub.com/metaprov/modelaapi/pkg/apis/catalog/v1alpha1/generated.proto\x1a\"k8s.io/api/core/v1/generated.proto\"\xf5\x07\n\x0cTrainRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\x06\x62ucket\x18\x03 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12N\n\x05model\x18\x05 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12N\n\x05study\x18\x06 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12T\n\ndatasource\x18\x07 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x08 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12U\n\nconnection\x18\t \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\\\n\x06secret\x18\n \x03(\x0b\x32L.github.com.metaprov.modelaapi.services.trainerd.v1.TrainRequest.SecretEntry\x12R\n\x0btestDataset\x18\x0b \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12S\n\x0ctrainDataset\x18\x0c \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12\r\n\x05group\x18\r \x01(\x08\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\x88\x08\n\rTrainResponse\x12T\n\x06result\x18\x01 \x03(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Measurement\x12\x17\n\x0fweightsCloudUri\x18\x02 \x01(\t\x12\x18\n\x10manifestCloudUri\x18\x03 \x01(\t\x12\x14\n\x0clogsCloudUri\x18\x04 \x01(\t\x12\x14\n\x0clabelEncoder\x18\x05 \x01(\t\x12\x19\n\x11pythonVersionInfo\x18\x06 \x01(\t\x12\x11\n\tpythonCMD\x18\x07 \x01(\t\x12\n\n\x02OS\x18\x08 \x01(\t\x12\x63\n\tpipFreeze\x18\t \x03(\x0b\x32P.github.com.metaprov.modelaapi.services.trainerd.v1.TrainResponse.PipFreezeEntry\x12\x83\x01\n\x19impurityFeatureImportance\x18\n \x03(\x0b\x32`.github.com.metaprov.modelaapi.services.trainerd.v1.TrainResponse.ImpurityFeatureImportanceEntry\x12\x89\x01\n\x1cpermutationFeatureImportance\x18\x0b \x03(\x0b\x32\x63.github.com.metaprov.modelaapi.services.trainerd.v1.TrainResponse.PermutationFeatureImportanceEntry\x12T\n\x02\x63m\x18\x0c \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ConfusionMatrix\x12\x15\n\rmodelIndexURI\x18\r \x01(\t\x12\x13\n\x0b\x66orecastURI\x18\x0e \x01(\t\x12V\n\x08\x66\x65\x61tures\x18\x0f \x03(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Measurement\x1a\x30\n\x0ePipFreezeEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a@\n\x1eImpurityFeatureImportanceEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\x1a\x43\n!PermutationFeatureImportanceEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\"\xc1\x06\n\x0e\x43ompileRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\x06\x62ucket\x18\x03 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12N\n\x05model\x18\x05 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12N\n\x05study\x18\x06 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12T\n\ndatasource\x18\x07 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x08 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12U\n\nconnection\x18\t \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12^\n\x06secret\x18\n \x03(\x0b\x32N.github.com.metaprov.modelaapi.services.trainerd.v1.CompileRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"+\n\x0f\x43ompileResponse\x12\x18\n\x10\x63ompiledModelUri\x18\x01 \x01(\t\"\xca\x06\n\x0bTestRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\x06\x62ucket\x18\x03 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12N\n\x05model\x18\x05 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12N\n\x05study\x18\x06 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12T\n\ndatasource\x18\x07 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x08 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12U\n\nconnection\x18\t \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12[\n\x06secret\x18\n \x03(\x0b\x32K.github.com.metaprov.modelaapi.services.trainerd.v1.TestRequest.SecretEntry\x12\r\n\x05group\x18\x0b \x01(\x08\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\x96\n\n\x0cTestResponse\x12Z\n\x0ctrain_result\x18\x01 \x03(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Measurement\x12Y\n\x0btest_result\x18\x02 \x03(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Measurement\x12^\n\x10\x62\x65nchmark_result\x18\x03 \x03(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Measurement\x12\x1c\n\x14modelWeightsCloudUri\x18\x04 \x01(\t\x12\x1d\n\x15modelManifestCloudUri\x18\x05 \x01(\t\x12\x19\n\x11modelLogsCloudUri\x18\x06 \x01(\t\x12\x1a\n\x12preWeightsCloudUri\x18\x07 \x01(\t\x12\x1b\n\x13preManifestCloudUri\x18\x08 \x01(\t\x12\x17\n\x0fpreLogsCloudUri\x18\t \x01(\t\x12\x14\n\x0clabelEncoder\x18\n \x01(\t\x12\x11\n\tpythonCMD\x18\x0b \x01(\t\x12\n\n\x02OS\x18\x0c \x01(\t\x12\x19\n\x11pythonVersionInfo\x18\r \x01(\t\x12\x62\n\tpipFreeze\x18\x0e \x03(\x0b\x32O.github.com.metaprov.modelaapi.services.trainerd.v1.TestResponse.PipFreezeEntry\x12\x13\n\x0bmisclassUri\x18\x0f \x01(\t\x12\x82\x01\n\x19impurityFeatureImportance\x18\x10 \x03(\x0b\x32_.github.com.metaprov.modelaapi.services.trainerd.v1.TestResponse.ImpurityFeatureImportanceEntry\x12\x88\x01\n\x1cpermutationFeatureImportance\x18\x11 \x03(\x0b\x32\x62.github.com.metaprov.modelaapi.services.trainerd.v1.TestResponse.PermutationFeatureImportanceEntry\x12Y\n\x07trainCM\x18\x12 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ConfusionMatrix\x12X\n\x06testCM\x18\x13 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ConfusionMatrix\x1a\x30\n\x0ePipFreezeEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a@\n\x1eImpurityFeatureImportanceEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\x1a\x43\n!PermutationFeatureImportanceEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\"\xab\x07\n\x14TrainEnsembleRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\x06\x62ucket\x18\x03 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12M\n\x04\x62\x61se\x18\x05 \x03(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12N\n\x05model\x18\x06 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12N\n\x05study\x18\x07 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12T\n\ndatasource\x18\x08 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\t \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12U\n\nconnection\x18\n \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x64\n\x06secret\x18\x0b \x03(\x0b\x32T.github.com.metaprov.modelaapi.services.trainerd.v1.TrainEnsembleRequest.SecretEntry\x12\r\n\x05group\x18\x0c \x01(\x08\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\xa9\x07\n\x13TestEnsembleRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\x06\x62ucket\x18\x03 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12M\n\x04\x62\x61se\x18\x05 \x03(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12N\n\x05model\x18\x06 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12N\n\x05study\x18\x07 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12T\n\ndatasource\x18\x08 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\t \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12U\n\nconnection\x18\n \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x63\n\x06secret\x18\x0b \x03(\x0b\x32S.github.com.metaprov.modelaapi.services.trainerd.v1.TestEnsembleRequest.SecretEntry\x12\r\n\x05group\x18\x0c \x01(\x08\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\xb5\x07\n\x19TrainDriftDetectorRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\x06\x62ucket\x18\x03 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12M\n\x04\x62\x61se\x18\x05 \x03(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12N\n\x05model\x18\x06 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12N\n\x05study\x18\x07 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12T\n\ndatasource\x18\x08 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\t \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12U\n\nconnection\x18\n \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12i\n\x06secret\x18\x0b \x03(\x0b\x32Y.github.com.metaprov.modelaapi.services.trainerd.v1.TrainDriftDetectorRequest.SecretEntry\x12\r\n\x05group\x18\x0c \x01(\x08\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\xd2\x06\n\x0f\x46orecastRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\x06\x62ucket\x18\x03 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12N\n\x05model\x18\x05 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12N\n\x05study\x18\x06 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12T\n\ndatasource\x18\x07 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x08 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12U\n\nconnection\x18\t \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12_\n\x06secret\x18\n \x03(\x0b\x32O.github.com.metaprov.modelaapi.services.trainerd.v1.ForecastRequest.SecretEntry\x12\r\n\x05group\x18\x0b \x01(\x08\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\",\n\x10\x46orecastResponse\x12\x18\n\x10\x66orecastCloudUri\x18\x02 \x01(\t\"\x11\n\x0fShutdownRequest\"\x12\n\x10ShutdownResponse\"\xd0\x06\n\x0e\x45xplainRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\x06\x62ucket\x18\x03 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12N\n\x05model\x18\x05 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12N\n\x05study\x18\x06 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12T\n\ndatasource\x18\x07 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x08 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12U\n\nconnection\x18\t \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12^\n\x06secret\x18\n \x03(\x0b\x32N.github.com.metaprov.modelaapi.services.trainerd.v1.ExplainRequest.SecretEntry\x12\r\n\x05group\x18\x0b \x01(\x08\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\x9e\x02\n\x0f\x45xplainResponse\x12\x14\n\x0c\x65xplainerUri\x18\x01 \x01(\t\x12\x1a\n\x12trainShapValuesUri\x18\x02 \x01(\t\x12\x19\n\x11testShapValuesUri\x18\x03 \x01(\t\x12\x7f\n\x16shapFeaturesImportance\x18\x04 \x03(\x0b\x32_.github.com.metaprov.modelaapi.services.trainerd.v1.ExplainResponse.ShapFeaturesImportanceEntry\x1a=\n\x1bShapFeaturesImportanceEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\x32\xe5\t\n\x0fTrainerdService\x12\x8e\x01\n\x05Train\x12@.github.com.metaprov.modelaapi.services.trainerd.v1.TrainRequest\x1a\x41.github.com.metaprov.modelaapi.services.trainerd.v1.TrainResponse\"\x00\x12\x94\x01\n\x07\x45xplain\x12\x42.github.com.metaprov.modelaapi.services.trainerd.v1.ExplainRequest\x1a\x43.github.com.metaprov.modelaapi.services.trainerd.v1.ExplainResponse\"\x00\x12\x97\x01\n\x08\x46orecast\x12\x43.github.com.metaprov.modelaapi.services.trainerd.v1.ForecastRequest\x1a\x44.github.com.metaprov.modelaapi.services.trainerd.v1.ForecastResponse\"\x00\x12\x8b\x01\n\x04Test\x12?.github.com.metaprov.modelaapi.services.trainerd.v1.TestRequest\x1a@.github.com.metaprov.modelaapi.services.trainerd.v1.TestResponse\"\x00\x12\x9e\x01\n\rTrainEnsemble\x12H.github.com.metaprov.modelaapi.services.trainerd.v1.TrainEnsembleRequest\x1a\x41.github.com.metaprov.modelaapi.services.trainerd.v1.TrainResponse\"\x00\x12\xa8\x01\n\x12TrainDriftDetector\x12M.github.com.metaprov.modelaapi.services.trainerd.v1.TrainDriftDetectorRequest\x1a\x41.github.com.metaprov.modelaapi.services.trainerd.v1.TrainResponse\"\x00\x12\x9b\x01\n\x0cTestEnsemble\x12G.github.com.metaprov.modelaapi.services.trainerd.v1.TestEnsembleRequest\x1a@.github.com.metaprov.modelaapi.services.trainerd.v1.TestResponse\"\x00\x12\x97\x01\n\x08Shutdown\x12\x43.github.com.metaprov.modelaapi.services.trainerd.v1.ShutdownRequest\x1a\x44.github.com.metaprov.modelaapi.services.trainerd.v1.ShutdownResponse\"\x00\x42\x34Z2github.com/metaprov/modelaapi/services/trainerd/v1b\x06proto3')



_TRAINREQUEST = DESCRIPTOR.message_types_by_name['TrainRequest']
_TRAINREQUEST_SECRETENTRY = _TRAINREQUEST.nested_types_by_name['SecretEntry']
_TRAINRESPONSE = DESCRIPTOR.message_types_by_name['TrainResponse']
_TRAINRESPONSE_PIPFREEZEENTRY = _TRAINRESPONSE.nested_types_by_name['PipFreezeEntry']
_TRAINRESPONSE_IMPURITYFEATUREIMPORTANCEENTRY = _TRAINRESPONSE.nested_types_by_name['ImpurityFeatureImportanceEntry']
_TRAINRESPONSE_PERMUTATIONFEATUREIMPORTANCEENTRY = _TRAINRESPONSE.nested_types_by_name['PermutationFeatureImportanceEntry']
_COMPILEREQUEST = DESCRIPTOR.message_types_by_name['CompileRequest']
_COMPILEREQUEST_SECRETENTRY = _COMPILEREQUEST.nested_types_by_name['SecretEntry']
_COMPILERESPONSE = DESCRIPTOR.message_types_by_name['CompileResponse']
_TESTREQUEST = DESCRIPTOR.message_types_by_name['TestRequest']
_TESTREQUEST_SECRETENTRY = _TESTREQUEST.nested_types_by_name['SecretEntry']
_TESTRESPONSE = DESCRIPTOR.message_types_by_name['TestResponse']
_TESTRESPONSE_PIPFREEZEENTRY = _TESTRESPONSE.nested_types_by_name['PipFreezeEntry']
_TESTRESPONSE_IMPURITYFEATUREIMPORTANCEENTRY = _TESTRESPONSE.nested_types_by_name['ImpurityFeatureImportanceEntry']
_TESTRESPONSE_PERMUTATIONFEATUREIMPORTANCEENTRY = _TESTRESPONSE.nested_types_by_name['PermutationFeatureImportanceEntry']
_TRAINENSEMBLEREQUEST = DESCRIPTOR.message_types_by_name['TrainEnsembleRequest']
_TRAINENSEMBLEREQUEST_SECRETENTRY = _TRAINENSEMBLEREQUEST.nested_types_by_name['SecretEntry']
_TESTENSEMBLEREQUEST = DESCRIPTOR.message_types_by_name['TestEnsembleRequest']
_TESTENSEMBLEREQUEST_SECRETENTRY = _TESTENSEMBLEREQUEST.nested_types_by_name['SecretEntry']
_TRAINDRIFTDETECTORREQUEST = DESCRIPTOR.message_types_by_name['TrainDriftDetectorRequest']
_TRAINDRIFTDETECTORREQUEST_SECRETENTRY = _TRAINDRIFTDETECTORREQUEST.nested_types_by_name['SecretEntry']
_FORECASTREQUEST = DESCRIPTOR.message_types_by_name['ForecastRequest']
_FORECASTREQUEST_SECRETENTRY = _FORECASTREQUEST.nested_types_by_name['SecretEntry']
_FORECASTRESPONSE = DESCRIPTOR.message_types_by_name['ForecastResponse']
_SHUTDOWNREQUEST = DESCRIPTOR.message_types_by_name['ShutdownRequest']
_SHUTDOWNRESPONSE = DESCRIPTOR.message_types_by_name['ShutdownResponse']
_EXPLAINREQUEST = DESCRIPTOR.message_types_by_name['ExplainRequest']
_EXPLAINREQUEST_SECRETENTRY = _EXPLAINREQUEST.nested_types_by_name['SecretEntry']
_EXPLAINRESPONSE = DESCRIPTOR.message_types_by_name['ExplainResponse']
_EXPLAINRESPONSE_SHAPFEATURESIMPORTANCEENTRY = _EXPLAINRESPONSE.nested_types_by_name['ShapFeaturesImportanceEntry']
TrainRequest = _reflection.GeneratedProtocolMessageType('TrainRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _TRAINREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.trainerd.v1.trainerd_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.trainerd.v1.TrainRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _TRAINREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.trainerd.v1.trainerd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.trainerd.v1.TrainRequest)
  })
_sym_db.RegisterMessage(TrainRequest)
_sym_db.RegisterMessage(TrainRequest.SecretEntry)

TrainResponse = _reflection.GeneratedProtocolMessageType('TrainResponse', (_message.Message,), {

  'PipFreezeEntry' : _reflection.GeneratedProtocolMessageType('PipFreezeEntry', (_message.Message,), {
    'DESCRIPTOR' : _TRAINRESPONSE_PIPFREEZEENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.trainerd.v1.trainerd_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.trainerd.v1.TrainResponse.PipFreezeEntry)
    })
  ,

  'ImpurityFeatureImportanceEntry' : _reflection.GeneratedProtocolMessageType('ImpurityFeatureImportanceEntry', (_message.Message,), {
    'DESCRIPTOR' : _TRAINRESPONSE_IMPURITYFEATUREIMPORTANCEENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.trainerd.v1.trainerd_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.trainerd.v1.TrainResponse.ImpurityFeatureImportanceEntry)
    })
  ,

  'PermutationFeatureImportanceEntry' : _reflection.GeneratedProtocolMessageType('PermutationFeatureImportanceEntry', (_message.Message,), {
    'DESCRIPTOR' : _TRAINRESPONSE_PERMUTATIONFEATUREIMPORTANCEENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.trainerd.v1.trainerd_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.trainerd.v1.TrainResponse.PermutationFeatureImportanceEntry)
    })
  ,
  'DESCRIPTOR' : _TRAINRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.trainerd.v1.trainerd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.trainerd.v1.TrainResponse)
  })
_sym_db.RegisterMessage(TrainResponse)
_sym_db.RegisterMessage(TrainResponse.PipFreezeEntry)
_sym_db.RegisterMessage(TrainResponse.ImpurityFeatureImportanceEntry)
_sym_db.RegisterMessage(TrainResponse.PermutationFeatureImportanceEntry)

CompileRequest = _reflection.GeneratedProtocolMessageType('CompileRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _COMPILEREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.trainerd.v1.trainerd_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.trainerd.v1.CompileRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _COMPILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.trainerd.v1.trainerd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.trainerd.v1.CompileRequest)
  })
_sym_db.RegisterMessage(CompileRequest)
_sym_db.RegisterMessage(CompileRequest.SecretEntry)

CompileResponse = _reflection.GeneratedProtocolMessageType('CompileResponse', (_message.Message,), {
  'DESCRIPTOR' : _COMPILERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.trainerd.v1.trainerd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.trainerd.v1.CompileResponse)
  })
_sym_db.RegisterMessage(CompileResponse)

TestRequest = _reflection.GeneratedProtocolMessageType('TestRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _TESTREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.trainerd.v1.trainerd_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.trainerd.v1.TestRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _TESTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.trainerd.v1.trainerd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.trainerd.v1.TestRequest)
  })
_sym_db.RegisterMessage(TestRequest)
_sym_db.RegisterMessage(TestRequest.SecretEntry)

TestResponse = _reflection.GeneratedProtocolMessageType('TestResponse', (_message.Message,), {

  'PipFreezeEntry' : _reflection.GeneratedProtocolMessageType('PipFreezeEntry', (_message.Message,), {
    'DESCRIPTOR' : _TESTRESPONSE_PIPFREEZEENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.trainerd.v1.trainerd_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.trainerd.v1.TestResponse.PipFreezeEntry)
    })
  ,

  'ImpurityFeatureImportanceEntry' : _reflection.GeneratedProtocolMessageType('ImpurityFeatureImportanceEntry', (_message.Message,), {
    'DESCRIPTOR' : _TESTRESPONSE_IMPURITYFEATUREIMPORTANCEENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.trainerd.v1.trainerd_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.trainerd.v1.TestResponse.ImpurityFeatureImportanceEntry)
    })
  ,

  'PermutationFeatureImportanceEntry' : _reflection.GeneratedProtocolMessageType('PermutationFeatureImportanceEntry', (_message.Message,), {
    'DESCRIPTOR' : _TESTRESPONSE_PERMUTATIONFEATUREIMPORTANCEENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.trainerd.v1.trainerd_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.trainerd.v1.TestResponse.PermutationFeatureImportanceEntry)
    })
  ,
  'DESCRIPTOR' : _TESTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.trainerd.v1.trainerd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.trainerd.v1.TestResponse)
  })
_sym_db.RegisterMessage(TestResponse)
_sym_db.RegisterMessage(TestResponse.PipFreezeEntry)
_sym_db.RegisterMessage(TestResponse.ImpurityFeatureImportanceEntry)
_sym_db.RegisterMessage(TestResponse.PermutationFeatureImportanceEntry)

TrainEnsembleRequest = _reflection.GeneratedProtocolMessageType('TrainEnsembleRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _TRAINENSEMBLEREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.trainerd.v1.trainerd_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.trainerd.v1.TrainEnsembleRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _TRAINENSEMBLEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.trainerd.v1.trainerd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.trainerd.v1.TrainEnsembleRequest)
  })
_sym_db.RegisterMessage(TrainEnsembleRequest)
_sym_db.RegisterMessage(TrainEnsembleRequest.SecretEntry)

TestEnsembleRequest = _reflection.GeneratedProtocolMessageType('TestEnsembleRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _TESTENSEMBLEREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.trainerd.v1.trainerd_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.trainerd.v1.TestEnsembleRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _TESTENSEMBLEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.trainerd.v1.trainerd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.trainerd.v1.TestEnsembleRequest)
  })
_sym_db.RegisterMessage(TestEnsembleRequest)
_sym_db.RegisterMessage(TestEnsembleRequest.SecretEntry)

TrainDriftDetectorRequest = _reflection.GeneratedProtocolMessageType('TrainDriftDetectorRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _TRAINDRIFTDETECTORREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.trainerd.v1.trainerd_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.trainerd.v1.TrainDriftDetectorRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _TRAINDRIFTDETECTORREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.trainerd.v1.trainerd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.trainerd.v1.TrainDriftDetectorRequest)
  })
_sym_db.RegisterMessage(TrainDriftDetectorRequest)
_sym_db.RegisterMessage(TrainDriftDetectorRequest.SecretEntry)

ForecastRequest = _reflection.GeneratedProtocolMessageType('ForecastRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _FORECASTREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.trainerd.v1.trainerd_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.trainerd.v1.ForecastRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _FORECASTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.trainerd.v1.trainerd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.trainerd.v1.ForecastRequest)
  })
_sym_db.RegisterMessage(ForecastRequest)
_sym_db.RegisterMessage(ForecastRequest.SecretEntry)

ForecastResponse = _reflection.GeneratedProtocolMessageType('ForecastResponse', (_message.Message,), {
  'DESCRIPTOR' : _FORECASTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.trainerd.v1.trainerd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.trainerd.v1.ForecastResponse)
  })
_sym_db.RegisterMessage(ForecastResponse)

ShutdownRequest = _reflection.GeneratedProtocolMessageType('ShutdownRequest', (_message.Message,), {
  'DESCRIPTOR' : _SHUTDOWNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.trainerd.v1.trainerd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.trainerd.v1.ShutdownRequest)
  })
_sym_db.RegisterMessage(ShutdownRequest)

ShutdownResponse = _reflection.GeneratedProtocolMessageType('ShutdownResponse', (_message.Message,), {
  'DESCRIPTOR' : _SHUTDOWNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.trainerd.v1.trainerd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.trainerd.v1.ShutdownResponse)
  })
_sym_db.RegisterMessage(ShutdownResponse)

ExplainRequest = _reflection.GeneratedProtocolMessageType('ExplainRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _EXPLAINREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.trainerd.v1.trainerd_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.trainerd.v1.ExplainRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _EXPLAINREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.trainerd.v1.trainerd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.trainerd.v1.ExplainRequest)
  })
_sym_db.RegisterMessage(ExplainRequest)
_sym_db.RegisterMessage(ExplainRequest.SecretEntry)

ExplainResponse = _reflection.GeneratedProtocolMessageType('ExplainResponse', (_message.Message,), {

  'ShapFeaturesImportanceEntry' : _reflection.GeneratedProtocolMessageType('ShapFeaturesImportanceEntry', (_message.Message,), {
    'DESCRIPTOR' : _EXPLAINRESPONSE_SHAPFEATURESIMPORTANCEENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.trainerd.v1.trainerd_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.trainerd.v1.ExplainResponse.ShapFeaturesImportanceEntry)
    })
  ,
  'DESCRIPTOR' : _EXPLAINRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.trainerd.v1.trainerd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.trainerd.v1.ExplainResponse)
  })
_sym_db.RegisterMessage(ExplainResponse)
_sym_db.RegisterMessage(ExplainResponse.ShapFeaturesImportanceEntry)

_TRAINERDSERVICE = DESCRIPTOR.services_by_name['TrainerdService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z2github.com/metaprov/modelaapi/services/trainerd/v1'
  _TRAINREQUEST_SECRETENTRY._options = None
  _TRAINREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _TRAINRESPONSE_PIPFREEZEENTRY._options = None
  _TRAINRESPONSE_PIPFREEZEENTRY._serialized_options = b'8\001'
  _TRAINRESPONSE_IMPURITYFEATUREIMPORTANCEENTRY._options = None
  _TRAINRESPONSE_IMPURITYFEATUREIMPORTANCEENTRY._serialized_options = b'8\001'
  _TRAINRESPONSE_PERMUTATIONFEATUREIMPORTANCEENTRY._options = None
  _TRAINRESPONSE_PERMUTATIONFEATUREIMPORTANCEENTRY._serialized_options = b'8\001'
  _COMPILEREQUEST_SECRETENTRY._options = None
  _COMPILEREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _TESTREQUEST_SECRETENTRY._options = None
  _TESTREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _TESTRESPONSE_PIPFREEZEENTRY._options = None
  _TESTRESPONSE_PIPFREEZEENTRY._serialized_options = b'8\001'
  _TESTRESPONSE_IMPURITYFEATUREIMPORTANCEENTRY._options = None
  _TESTRESPONSE_IMPURITYFEATUREIMPORTANCEENTRY._serialized_options = b'8\001'
  _TESTRESPONSE_PERMUTATIONFEATUREIMPORTANCEENTRY._options = None
  _TESTRESPONSE_PERMUTATIONFEATUREIMPORTANCEENTRY._serialized_options = b'8\001'
  _TRAINENSEMBLEREQUEST_SECRETENTRY._options = None
  _TRAINENSEMBLEREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _TESTENSEMBLEREQUEST_SECRETENTRY._options = None
  _TESTENSEMBLEREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _TRAINDRIFTDETECTORREQUEST_SECRETENTRY._options = None
  _TRAINDRIFTDETECTORREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _FORECASTREQUEST_SECRETENTRY._options = None
  _FORECASTREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _EXPLAINREQUEST_SECRETENTRY._options = None
  _EXPLAINREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _EXPLAINRESPONSE_SHAPFEATURESIMPORTANCEENTRY._options = None
  _EXPLAINRESPONSE_SHAPFEATURESIMPORTANCEENTRY._serialized_options = b'8\001'
  _TRAINREQUEST._serialized_start=446
  _TRAINREQUEST._serialized_end=1459
  _TRAINREQUEST_SECRETENTRY._serialized_start=1414
  _TRAINREQUEST_SECRETENTRY._serialized_end=1459
  _TRAINRESPONSE._serialized_start=1462
  _TRAINRESPONSE._serialized_end=2494
  _TRAINRESPONSE_PIPFREEZEENTRY._serialized_start=2311
  _TRAINRESPONSE_PIPFREEZEENTRY._serialized_end=2359
  _TRAINRESPONSE_IMPURITYFEATUREIMPORTANCEENTRY._serialized_start=2361
  _TRAINRESPONSE_IMPURITYFEATUREIMPORTANCEENTRY._serialized_end=2425
  _TRAINRESPONSE_PERMUTATIONFEATUREIMPORTANCEENTRY._serialized_start=2427
  _TRAINRESPONSE_PERMUTATIONFEATUREIMPORTANCEENTRY._serialized_end=2494
  _COMPILEREQUEST._serialized_start=2497
  _COMPILEREQUEST._serialized_end=3330
  _COMPILEREQUEST_SECRETENTRY._serialized_start=1414
  _COMPILEREQUEST_SECRETENTRY._serialized_end=1459
  _COMPILERESPONSE._serialized_start=3332
  _COMPILERESPONSE._serialized_end=3375
  _TESTREQUEST._serialized_start=3378
  _TESTREQUEST._serialized_end=4220
  _TESTREQUEST_SECRETENTRY._serialized_start=1414
  _TESTREQUEST_SECRETENTRY._serialized_end=1459
  _TESTRESPONSE._serialized_start=4223
  _TESTRESPONSE._serialized_end=5525
  _TESTRESPONSE_PIPFREEZEENTRY._serialized_start=2311
  _TESTRESPONSE_PIPFREEZEENTRY._serialized_end=2359
  _TESTRESPONSE_IMPURITYFEATUREIMPORTANCEENTRY._serialized_start=2361
  _TESTRESPONSE_IMPURITYFEATUREIMPORTANCEENTRY._serialized_end=2425
  _TESTRESPONSE_PERMUTATIONFEATUREIMPORTANCEENTRY._serialized_start=2427
  _TESTRESPONSE_PERMUTATIONFEATUREIMPORTANCEENTRY._serialized_end=2494
  _TRAINENSEMBLEREQUEST._serialized_start=5528
  _TRAINENSEMBLEREQUEST._serialized_end=6467
  _TRAINENSEMBLEREQUEST_SECRETENTRY._serialized_start=1414
  _TRAINENSEMBLEREQUEST_SECRETENTRY._serialized_end=1459
  _TESTENSEMBLEREQUEST._serialized_start=6470
  _TESTENSEMBLEREQUEST._serialized_end=7407
  _TESTENSEMBLEREQUEST_SECRETENTRY._serialized_start=1414
  _TESTENSEMBLEREQUEST_SECRETENTRY._serialized_end=1459
  _TRAINDRIFTDETECTORREQUEST._serialized_start=7410
  _TRAINDRIFTDETECTORREQUEST._serialized_end=8359
  _TRAINDRIFTDETECTORREQUEST_SECRETENTRY._serialized_start=1414
  _TRAINDRIFTDETECTORREQUEST_SECRETENTRY._serialized_end=1459
  _FORECASTREQUEST._serialized_start=8362
  _FORECASTREQUEST._serialized_end=9212
  _FORECASTREQUEST_SECRETENTRY._serialized_start=1414
  _FORECASTREQUEST_SECRETENTRY._serialized_end=1459
  _FORECASTRESPONSE._serialized_start=9214
  _FORECASTRESPONSE._serialized_end=9258
  _SHUTDOWNREQUEST._serialized_start=9260
  _SHUTDOWNREQUEST._serialized_end=9277
  _SHUTDOWNRESPONSE._serialized_start=9279
  _SHUTDOWNRESPONSE._serialized_end=9297
  _EXPLAINREQUEST._serialized_start=9300
  _EXPLAINREQUEST._serialized_end=10148
  _EXPLAINREQUEST_SECRETENTRY._serialized_start=1414
  _EXPLAINREQUEST_SECRETENTRY._serialized_end=1459
  _EXPLAINRESPONSE._serialized_start=10151
  _EXPLAINRESPONSE._serialized_end=10437
  _EXPLAINRESPONSE_SHAPFEATURESIMPORTANCEENTRY._serialized_start=10376
  _EXPLAINRESPONSE_SHAPFEATURESIMPORTANCEENTRY._serialized_end=10437
  _TRAINERDSERVICE._serialized_start=10440
  _TRAINERDSERVICE._serialized_end=11693
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: k8s.io/apimachinery/pkg/api/resource/generated.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4k8s.io/apimachinery/pkg/api/resource/generated.proto\x12$k8s.io.apimachinery.pkg.api.resource\"\x1a\n\x08Quantity\x12\x0e\n\x06string\x18\x01 \x01(\t\"\x1f\n\rQuantityValue\x12\x0e\n\x06string\x18\x01 \x01(\tB&Z$k8s.io/apimachinery/pkg/api/resource')



_QUANTITY = DESCRIPTOR.message_types_by_name['Quantity']
_QUANTITYVALUE = DESCRIPTOR.message_types_by_name['QuantityValue']
Quantity = _reflection.GeneratedProtocolMessageType('Quantity', (_message.Message,), {
  'DESCRIPTOR' : _QUANTITY,
  '__module__' : 'k8s.io.apimachinery.pkg.api.resource.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.api.resource.Quantity)
  })
_sym_db.RegisterMessage(Quantity)

QuantityValue = _reflection.GeneratedProtocolMessageType('QuantityValue', (_message.Message,), {
  'DESCRIPTOR' : _QUANTITYVALUE,
  '__module__' : 'k8s.io.apimachinery.pkg.api.resource.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.api.resource.QuantityValue)
  })
_sym_db.RegisterMessage(QuantityValue)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z$k8s.io/apimachinery/pkg/api/resource'
  _QUANTITY._serialized_start=94
  _QUANTITY._serialized_end=120
  _QUANTITYVALUE._serialized_start=122
  _QUANTITYVALUE._serialized_end=153
# @@protoc_insertion_point(module_scope)
